@@ -81,7 +81,15 @@ class Redis(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Redis.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                replicas: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = RedisOptions(labels=labels, replicas=replicas)
@@ -126,7 +134,13 @@ class RedisOptions:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RedisOptions.__init__)
+            def stub(
+                *,
+                labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                replicas: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument replicas", value=replicas, expected_type=type_hints["replicas"])
         self._values: typing.Dict[str, typing.Any] = {}
